==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebMoveFloatingPaneActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebMoveFloatingPaneActionDescription } from "./WebMoveFloatingPaneActionDescription";
/**
 * @hidden
 */
var WebMoveFloatingPaneActionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebMoveFloatingPaneActionDescriptionMetadata, _super);
    function WebMoveFloatingPaneActionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebMoveFloatingPaneActionDescriptionMetadata.b = function (a) {
        if (WebMoveFloatingPaneActionDescriptionMetadata.a == null) {
            WebMoveFloatingPaneActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebMoveFloatingPaneActionDescriptionMetadata.c(WebMoveFloatingPaneActionDescriptionMetadata.a);
        }
        if (a.g(WebMoveFloatingPaneActionDescriptionMetadata.a)) {
            return;
        }
        a.s(WebMoveFloatingPaneActionDescriptionMetadata.a);
        WebDockManagerPointDescriptionMetadata.d(a);
    };
    WebMoveFloatingPaneActionDescriptionMetadata.c = function (a) {
        WebPaneDragActionDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:MoveFloatingPaneAction");
        a.item("ActionType", "(wc:Type)ExportedType:string:PaneDragActionType");
        a.item("ActionType@names", "FloatPane;MoveFloatingPane;DockPane;MoveTab");
        a.item("OldLocation", "ExportedType:WebDockManagerPoint");
        a.item("NewLocation", "ExportedType:WebDockManagerPoint");
    };
    WebMoveFloatingPaneActionDescriptionMetadata.d = function (a) {
        WebMoveFloatingPaneActionDescriptionMetadata.b(a);
        a.u("WebMoveFloatingPaneAction", function () { return new WebMoveFloatingPaneActionDescription(); });
        a.t("WebMoveFloatingPaneAction", WebMoveFloatingPaneActionDescriptionMetadata.a);
    };
    WebMoveFloatingPaneActionDescriptionMetadata.$t = markType(WebMoveFloatingPaneActionDescriptionMetadata, 'WebMoveFloatingPaneActionDescriptionMetadata');
    WebMoveFloatingPaneActionDescriptionMetadata.a = null;
    return WebMoveFloatingPaneActionDescriptionMetadata;
}(Base));
export { WebMoveFloatingPaneActionDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebMoveFloatingPaneActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebMoveFloatingPaneActionDescription } from "./WebMoveFloatingPaneActionDescription";
/**
 * @hidden
 */
var WebMoveFloatingPaneActionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebMoveFloatingPaneActionDescriptionMetadata, _super);
    function WebMoveFloatingPaneActionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebMoveFloatingPaneActionDescriptionMetadata.b = function (a) {
        if (WebMoveFloatingPaneActionDescriptionMetadata.a == null) {
            WebMoveFloatingPaneActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebMoveFloatingPaneActionDescriptionMetadata.c(WebMoveFloatingPaneActionDescriptionMetadata.a);
        }
        if (a.j(WebMoveFloatingPaneActionDescriptionMetadata.a)) {
            return;
        }
        a.y(WebMoveFloatingPaneActionDescriptionMetadata.a);
        WebDockManagerPointDescriptionMetadata.d(a);
    };
    WebMoveFloatingPaneActionDescriptionMetadata.c = function (a) {
        WebPaneDragActionDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:MoveFloatingPaneAction");
        a.item("ActionType", "(wc:Type)ExportedType:string:PaneDragActionType");
        a.item("ActionType@names", "FloatPane;MoveFloatingPane;DockPane;MoveTab");
        a.item("OldLocation", "ExportedType:WebDockManagerPoint");
        a.item("NewLocation", "ExportedType:WebDockManagerPoint");
    };
    WebMoveFloatingPaneActionDescriptionMetadata.d = function (a) {
        WebMoveFloatingPaneActionDescriptionMetadata.b(a);
        a.aa("WebMoveFloatingPaneAction", function () { return new WebMoveFloatingPaneActionDescription(); });
        a.z("WebMoveFloatingPaneAction", WebMoveFloatingPaneActionDescriptionMetadata.a);
    };
    WebMoveFloatingPaneActionDescriptionMetadata.$t = markType(WebMoveFloatingPaneActionDescriptionMetadata, 'WebMoveFloatingPaneActionDescriptionMetadata');
    WebMoveFloatingPaneActionDescriptionMetadata.a = null;
    return WebMoveFloatingPaneActionDescriptionMetadata;
}(Base));
export { WebMoveFloatingPaneActionDescriptionMetadata };
